==> mfc-api-model-0.1.1-sources.jar: com/valor/mfc/vms/api/model/uac/LoginInfoDo.java <==
package com.valor.mfc.vms.api.model.uac;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;
import com.valor.mfc.vms.api.model.user.UserInfoDO;

/**
 * Created by Frank.Huang on 2016/7/13.
 */
public class LoginInfoDo extends AbstractPrintable {

    private String did = "";
    private long uid = 0;
    private long serverTimeMS = System.currentTimeMillis();
    private String token;
    private long expireMS;
    private long expireTimeMS;
    private UserInfoDO userInfo;
    private String st = "";
    private int switchLogo = 1;//0=OFF,1=ON

    private int isAllowLoginCode  = 0;//0=OFF,1=ON


    private long vendorId=0;
    private String bizDisplayMsg="";

    private String model="";

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public long getUid() {
        return uid;
    }

    public void setUid(long uid) {
        this.uid = uid;
    }

    public long getServerTimeMS() {
        return serverTimeMS;
    }

    public void setServerTimeMS(long serverTimeMS) {
        this.serverTimeMS = serverTimeMS;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public long getExpireMS() {
        return expireMS;
    }

    public void setExpireMS(long expireMS) {
        this.expireMS = expireMS;
        this.expireTimeMS = this.serverTimeMS + this.expireMS;
    }

    public long getExpireTimeMS() {
        return expireTimeMS;
    }

    public void setExpireTimeMS(long expireTimeMS) {
        this.expireTimeMS = expireTimeMS;
    }

    public UserInfoDO getUserInfo() {
        return userInfo;
    }

    public void setUserInfo(UserInfoDO userInfo) {
        this.userInfo = userInfo;
    }

    public String getSt() {
        return st;
    }

    public void setSt(String st) {
        this.st = st;
    }

    public int getSwitchLogo() {
        return switchLogo;
    }

    public void setSwitchLogo(int switchLogo) {
        this.switchLogo = switchLogo;
    }

    public int getIsAllowLoginCode() {
        return isAllowLoginCode;
    }

    public void setIsAllowLoginCode(int isAllowLoginCode) {
        this.isAllowLoginCode = isAllowLoginCode;
    }

    public long getVendorId() {
        return vendorId;
    }

    public void setVendorId(long vendorId) {
        this.vendorId = vendorId;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public String getBizDisplayMsg() {
        return bizDisplayMsg;
    }

    public void setBizDisplayMsg(String bizDisplayMsg) {
        this.bizDisplayMsg = bizDisplayMsg;
    }
}

==> mfc-api-model-0.1.2-sources.jar: com/valor/mfc/vms/api/model/uac/LoginInfoDo.java <==
package com.valor.mfc.vms.api.model.uac;

import com.google.common.collect.Maps;
import com.valor.mfc.vms.api.model.common.AbstractPrintable;
import com.valor.mfc.vms.api.model.user.UserInfoDO;

import java.util.Map;

/**
 * Created by Frank.Huang on 2016/7/13.
 */
public class LoginInfoDo extends AbstractPrintable {

    private String did = "";
    private long uid = 0;
    private long serverTimeMS = System.currentTimeMillis();
    private String token;
    private long expireMS;
    private long expireTimeMS;
    private UserInfoDO userInfo;
    private String st = "";
    private int switchLogo = 1;//0=OFF,1=ON

    private int isAllowLoginCode = 0;//0=OFF,1=ON
    private long vendorId = 0;
    private String bizDisplayMsg = "";
    private String model = "";
    private long connectId;
    private String streamToken;
    private String bindingSerialNumber;

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public long getUid() {
        return uid;
    }

    public void setUid(long uid) {
        this.uid = uid;
    }

    public long getServerTimeMS() {
        return serverTimeMS;
    }

    public void setServerTimeMS(long serverTimeMS) {
        this.serverTimeMS = serverTimeMS;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public long getExpireMS() {
        return expireMS;
    }

    public void setExpireMS(long expireMS) {
        this.expireMS = expireMS;
        this.expireTimeMS = this.serverTimeMS + this.expireMS;
    }

    public long getExpireTimeMS() {
        return expireTimeMS;
    }

    public void setExpireTimeMS(long expireTimeMS) {
        this.expireTimeMS = expireTimeMS;
    }

    public UserInfoDO getUserInfo() {
        return userInfo;
    }

    public void setUserInfo(UserInfoDO userInfo) {
        this.userInfo = userInfo;
    }

    public String getSt() {
        return st;
    }

    public void setSt(String st) {
        this.st = st;
    }

    public int getSwitchLogo() {
        return switchLogo;
    }

    public void setSwitchLogo(int switchLogo) {
        this.switchLogo = switchLogo;
    }

    public int getIsAllowLoginCode() {
        return isAllowLoginCode;
    }

    public void setIsAllowLoginCode(int isAllowLoginCode) {
        this.isAllowLoginCode = isAllowLoginCode;
    }

    public long getVendorId() {
        return vendorId;
    }

    public void setVendorId(long vendorId) {
        this.vendorId = vendorId;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public String getBizDisplayMsg() {
        return bizDisplayMsg;
    }

    public void setBizDisplayMsg(String bizDisplayMsg) {
        this.bizDisplayMsg = bizDisplayMsg;
    }


    public long getConnectId() {
        return connectId;
    }

    public void setConnectId(long connectId) {
        this.connectId = connectId;
    }

    public String getStreamToken() {
        return streamToken;
    }

    public void setStreamToken(String streamToken) {
        this.streamToken = streamToken;
    }

    public String getBindingSerialNumber() {
        return bindingSerialNumber;
    }

    public void setBindingSerialNumber(String bindingSerialNumber) {
        this.bindingSerialNumber = bindingSerialNumber;
    }
}
